freitag.core


queryclj

(query {:keys [country year month state]})

Queries for vacation days for the given country, year, month, and (optional) state

Queries for vacation days for the given country, year, month, and (optional) state
sourceraw docstring

root-pathclj

source

vacationsclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries