freitag.core


queryclj

(query {:keys [country year month state]})

Queries for vacation days for the given country, year, month, and (optional) state

Queries for vacation days for the given country, year, month, and (optional) state
sourceraw docstring

read-fileclj

(read-file path)

Reads the EDN from the file at the given path. Extracts country and year from the path structure

Reads the EDN from the file at the given path. Extracts country and year from the path structure
sourceraw docstring

root-pathclj

source

vacationsclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries