(query {:keys [country year month state]})Queries for vacation days for the given country, year, month, and (optional) state
Queries for vacation days for the given country, year, month, and (optional) state
(read-file path)Reads the EDN from the file at the given path. Extracts country and year from the path structure
Reads the EDN from the file at the given path. Extracts country and year from the path structure
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |