freitag.core


country-structureclj

(country-structure country)
source

load-allclj

(load-all)
source

queryclj

(query {:keys [country year month state]})

Queries for vacation days for the given country, year, month, and (optional) state

Queries for vacation days for the given country, year, month, and (optional) state
sourceraw docstring

vacationsclj

source

year-structureclj

(year-structure year)
source

cljdoc builds & hosts documentation for Clojure/Script libraries